---
title: <span class="badge object-type-scalar"></span> Hectopascals
---
# <span class="badge object-type-scalar"></span> Hectopascals

Pressure: Hectopascals

## Definition

```python
# Pressure: Hectopascals
Hectopascals: typing.Literal["pressurehpa"] = "pressurehpa"
```
